@@ -23,9 +23,6 @@ start_date, end_date as string "yyyy-mm-dd"
 OPTIONAL INPUTS: 
 
 
-- admin_account: dictionary with name and id. 
-                Optional, by default it gets 'Be You', 'Humable','Linkers',,'Miss Tariffa Agency','Numbers','Wearefiber', 'ELLEGIEFFE'
-
 
 - yaml_file_path: the path of 'googleads.yaml'. 
                 Optional, but mandatory to have it in same folder script if used the default parameter.
@@ -33,16 +30,10 @@ OPTIONAL INPUTS:
 """
 
 
-def get_google_ads(start_date, end_date,
+def get_google_ads(start_date, end_date, admin_account,
                    
-                  admin_account = {'Be You': '291-824-5921'
-                                 ,'Humable': '760-045-3647'
-                                 ,'Linkers': '504-714-3560'
-                                 ,'Miss Tariffa Agency': '427-886-1215'
-                                 ,'Numbers': '794-577-9076'
-                                 ,'Wearefiber': '778-681-5313'
-                                  ,'ELLEGIEFFE SRL':'643-277-1546'
-                                },
+                   
+                   ## optional
                    
                    yaml_file_path = 'googleads.yaml'
                   ):
