@@ -423,7 +423,12 @@ class Query:
                 elif isinstance(where_condition.operator, SQLOperator) or isinstance(where_condition.operator,
                                                                                      TimeOperator):
                     operator = where_condition.operator.name
-                    if operator == "GOE":
+                    if operator == "IN":
+                        if where_condition.negate is None:
+                            operator = where_condition.operator.name
+                        else:
+                            operator = "NOT " + where_condition.operator.name
+                    elif operator == "GOE":
                         if where_condition.negate is None:
                             operator = ">="
                         else:
@@ -517,15 +522,7 @@ class Query:
             spell_str += ', "group_by":['
             groupby_vec = []
             for clause in self.groupBy:
-                new_field = Field(column=clause.field.column,
-                                  alias=None,
-                                  aggregation=clause.field.aggregation,
-                                  sourceDataType=clause.field.sourceDataType,
-                                  internalDataType=clause.field.internalDataType,
-                                  sourceFormat=clause.field.sourceFormat,
-                                  sqlExpression=clause.field.sqlExpression)
-                string = self._field_spell_out(new_field)
-                groupby_vec.append(string)
+                groupby_vec.append(clause.field.column)
             spell_str += ", ".join(groupby_vec) + "]"
 
         if self.orderBy is not None and self.orderBy:
